---
title: Example Markdown Page
author: Turbines Tester
date: 2024-06-11
template: base.html
---

# Example Markdown Page

This is a test page.

It uses a template.

Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.

## Some features

-   most of markdown syntax is supported
-   it uses `Python-Markdown` under the hood
-   **Bullet lists** are easy to create.
-   You can add [links](https://www.example.com).
-   Inline code: `print("Hello, world!")`
-   You can add your own CSS to make this look a bit nicer

### Block code

```python
def greet():
        print("Hello, Markdown!")
```

### Tables

Currently unstyled, but supported:

| Feature      | Supported |
| ------------ | --------- |
| Bullet Lists | Yes       |
| Links        | Yes       |
| Inline Code  | Yes       |
| Block Code   | Yes       |
| Tables       | Yes       |

### Conclusion

That's all for now.
